from distutils.core import setup 

setup (

name = 'nesterKick',
version = '1.3.1',
py_modules = ['nesterKick'],
author = 'hfpython',
author_email = 'hfpython@headfirstlabs.com',
url = 'http://www.headfirstlabs.com',
description = 'A simple printer of nested lists',

)
